Created via: 
```
git log --pretty=format:"%ad%x09%s" --date=short
```

## Changelog version 1.4.0 - 1.4.1
 
- 2019-05-17	Update VERSION.rst
- 2019-05-17	Added python 3 environment yaml file (removed pip dependency of srtm.py due to recent update in conda-forge), successfully tested installation of environment on linux;  updated version
- 2019-05-17	Merge branch 'master' of https://github.com/jgliss/geonum
- 2019-05-17	Updated email address in setup.py
- 2019-04-24	Added skipif marker in tests if NetCDF4 library is missing, updated affected tests
- 2019-04-24	Updated version and minor updates in geonum_env_py3.yml
- 2019-04-24	Added some exception cases in example scripts in case srtm.py is not installed, so that RUN_ALL_SCRIPTS.py makes it to the end
- 2019-04-24	Added new module with pytest markers and one test to be skippep in test_topodata.py in case of missing SRTM library
- 2019-04-22	Update README.rst
- 2019-04-22	Updated README and added Python 3 to setup.py
